<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ug" sourcelanguage="en">
<context>
    <name>Bubble</name>
    <message>
        <location filename="../dde-osd/src/notification/bubble.cpp" line="325"/>
        <source>1 new message</source>
        <translation>1 يېڭى ئۇچۇر</translation>
    </message>
</context>
<context>
    <name>BubbleItem</name>
    <message>
        <location filename="../dde-osd/src/notification-center/bubbleitem.cpp" line="232"/>
        <source>Just Now</source>
        <translation>بايىلا</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/notification-center/bubbleitem.cpp" line="234"/>
        <source>%1 minutes ago</source>
        <translation>%1 مىنۇت بۇرۇن</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/notification-center/bubbleitem.cpp" line="236"/>
        <source>%1 hours ago</source>
        <translation>%1 سائەت بۇرۇن</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/notification-center/bubbleitem.cpp" line="239"/>
        <source>Yesterday </source>
        <translation>تۈنۈگۈن</translation>
    </message>
</context>
<context>
    <name>Content</name>
    <message>
        <location filename="../dde-license-dialog/src/content.cpp" line="272"/>
        <source>Cancel</source>
        <translation>بىكار قىلىش</translation>
    </message>
    <message>
        <location filename="../dde-license-dialog/src/content.cpp" line="273"/>
        <source>Confirm</source>
        <translation>جەزملەشتۈرۈش</translation>
    </message>
</context>
<context>
    <name>DMemoryWarningDialog</name>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="49"/>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="88"/>
        <source>Cancel</source>
        <translation>بىكار قىلىش</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="51"/>
        <source>Release</source>
        <translation>قويۇپ بېرىش</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="55"/>
        <source>This application will be ended, please make sure your data has been saved!</source>
        <translation>قوللىنىشچان ئىچكى ساقلىغۇچ قويۇپ بېرىلىدۇ، نۆۋەتتىكى سانلىق مەلۇماتنىڭ ساقلانغان ياكى ساقلانمىغانلىقىنى جەزملەشتۈرۈڭ.</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="56"/>
        <source>Please save your document, text and spreadsheet</source>
        <translation>ھۆججەت، تېكىست، جەدۋەل قاتارلىق سانلىق مەلۇماتلار.</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="89"/>
        <source>Continue</source>
        <translation>داۋاملاشتۇرۇش</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="110"/>
        <source>Insufficient system memory, please end some applications to avoid getting stuck.</source>
        <translation>نۆۋەتتىكى سىستېما ئىچكى ساقلىغۇچ  يېتەرلىك ئەمەس، قېتىۋېلىشنىڭ ئالدىنى ئېلىش ئۈچۈن مۇناسىۋەتلىك قوللىنىشچان ئىچكى ساقلىغۇچنى قويۇپ بېرىڭ!</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="222"/>
        <source>Continue to run %1, %2MB memory is required</source>
        <translation>ئەگەر %1 ئەپنى داۋاملىق ئىشلەتسىڭىز %2 MB ئىچكى ساقلىغۇچ قويۇپ بېرىڭ!</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="225"/>
        <source>Continue to open browser tab, %1MB memory is required</source>
        <translation>ئەگەر توركۆرگۈ بەتكۈچىنى داۋاملىق ئاچسىڭىز %1 MB ئىچكى ساقلىغۇچ قويۇپ بېرىڭ</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="228"/>
        <source>To continue the operation, %1MB memory is required</source>
        <translation>ئەگەر داۋاملىق بۇيرۇقنى ئىجرا قىلسىڭىز %1 MB ئىچكى ساقلىغۇچ قويۇپ بېرىڭ!</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="234"/>
        <source>Your current memory is sufficient enough, continue to run %1?</source>
        <translation>نۆۋەتتىكى ئىچكى ساقلىغۇچڭىز يېتەرلىك. %1 ئەپنى داۋاملاشتۇرامسىز؟</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="237"/>
        <source>Your current memory is sufficient enough, continue to open browser tab?</source>
        <translation>نۆۋەتتىكى ئىچكى ساقلىغۇچ يېتەرلىك ، توركۆرگۈ بەتكۈچىنى داۋاملىق ئاچماقچىمۇ؟</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="240"/>
        <source>Your current memory is sufficient enough, continue the operation?</source>
        <translation>ھازىرقى ئىچكى ساقلىغۇچ يېتەرلىك، بۇيرۇقنى داۋاملىق ئىجرا قىلامسىز؟</translation>
    </message>
</context>
<context>
    <name>DisplayModeProvider</name>
    <message>
        <location filename="../dde-osd/src/displaymodeprovider.cpp" line="292"/>
        <source>Only on %1</source>
        <translation>پەقەت %1 ئېكران</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/displaymodeprovider.cpp" line="294"/>
        <source>Duplicate</source>
        <translation>نۇسخىلاش</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/displaymodeprovider.cpp" line="296"/>
        <source>Extend</source>
        <translation>كېڭەيتىش</translation>
    </message>
</context>
<context>
    <name>KBLayoutIndicator</name>
    <message>
        <location filename="../dde-osd/src/kblayoutindicator.cpp" line="161"/>
        <source>Add keyboard layout</source>
        <translation>كۇنۇپكا تاختىسى ئورۇنلاشتۇرۇلۇشى قوشۇش</translation>
    </message>
</context>
<context>
    <name>NetworkSecretDialog</name>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="107"/>
        <source>Password required to connect &lt;font color=&quot;%1&quot;&gt;%2&lt;/font&gt;</source>
        <translation>&lt;font color=&quot;%1&quot;&gt;%2&lt;/font&gt; نى ئۇلاش ئۈچۈن پارول كىرگۈزۈڭ</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="179"/>
        <source>Wrong password, please enter again!</source>
        <translation>پارول خاتا، قايتا كىرگۈزۈڭ!</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="116"/>
        <source>Cancel</source>
        <translation>بىكار قىلىش</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="116"/>
        <source>Connect</source>
        <translation>ئۇلاش</translation>
    </message>
</context>
<context>
    <name>NotifyCenterWidget</name>
    <message>
        <location filename="../dde-osd/src/notification-center/notifycenterwidget.cpp" line="97"/>
        <source>Notification Center</source>
        <translation>ئۇقتۇرۇش مەركىزى</translation>
    </message>
</context>
<context>
    <name>NotifyWidget</name>
    <message>
        <location filename="../dde-osd/src/notification-center/notifywidget.cpp" line="40"/>
        <source>No system notifications</source>
        <translation>ھېچقانداق سىستېما ئۇقتۇرۇشى يوق</translation>
    </message>
</context>
<context>
    <name>OSDProvider</name>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="138"/>
        <source>Fn toggle</source>
        <translation>Fn ئالماشتۇرۇش</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="125"/>
        <source>WLAN on</source>
        <translation>WLAN ئېچىلدى</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="126"/>
        <source>WLAN off</source>
        <translation>WLAN تاقالدى</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="128"/>
        <source>Caps Lock on</source>
        <translation>Caps Lock ئوچۇق</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="129"/>
        <source>Caps Lock off</source>
        <translation>Caps Lock تاقاق</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="131"/>
        <source>Numeric keypad on</source>
        <translation>رەقەم تاختىسى ئېچىلدى</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="132"/>
        <source>Numeric keypad off</source>
        <translation>رەقەم تاختىسى تاقالدى</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="134"/>
        <source>Touchpad on</source>
        <translation>سېزىمچان تاختا ئېچىلدى</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="135"/>
        <source>Touchpad off</source>
        <translation>سېزىمچان تاختا تاقالدى</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="136"/>
        <source>Touchpad toggle</source>
        <translation>سېزىمچان تاختىنى ئالماشتۇرۇش</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="140"/>
        <source>Airplane mode on</source>
        <translation>ئۇچۇش ھالىتى ئېچىلدى</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="141"/>
        <source>Airplane mode off</source>
        <translation>ئۇچۇش ھالىتى تاقالدى</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="143"/>
        <source>Mute on</source>
        <translation>جىمجىت ھالەت ئېچىلدى</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="144"/>
        <source>Mute off</source>
        <translation>جىمجىت ھالەت تاقالدى</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="146"/>
        <source>Balanced power</source>
        <translation>تەڭپۇڭ ھالەت</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="147"/>
        <source>Power saver</source>
        <translation>ئېنېرگىيە تېجەش ھالىتى</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="148"/>
        <source>High performance</source>
        <translation>يۇقىرى ئىقتىدار ھالىتى</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="150"/>
        <source>Window effect enabled</source>
        <translation>ئېكران ئالاھىدە ئۈنۈمى ئېچىلدى</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="151"/>
        <source>Window effect disabled</source>
        <translation>كۆزنەك ئالاھىدە ئۈنۈمى تاقالدى</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="152"/>
        <source>Failed to enable window effects</source>
        <translation>ئېكران ئالاھىدە ئۈنۈمى ئېچىلمىدى</translation>
    </message>
</context>
<context>
    <name>PasswordWidget</name>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="57"/>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="146"/>
        <source>Passwords do not match</source>
        <translation>پارول بىردەك ئەمەس</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="65"/>
        <source>The hint is visible to all users. Do not include the password here.</source>
        <translation>پارول ئەسكەرتمىسى ھەممە ئادەمگە كۆرۈنىدۇ ، مەخپىي نومۇر قاتارلىق مۇھىم ئۇچۇرلار بولمىسۇن</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="86"/>
        <source>New Password</source>
        <translation>يېڭى پارول</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="120"/>
        <source>Repeat Password</source>
        <translation>پارولنى يەنە كىرگۈزۈڭ </translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="128"/>
        <source>Password Hint</source>
        <translation>پارول ئەسكەرتمىسى </translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="137"/>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="138"/>
        <source>Required</source>
        <translation>چوقۇم تولدۇرۇڭ</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="139"/>
        <source>Optional</source>
        <translation>ئىختىيارىي</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="221"/>
        <source>Strong</source>
        <translation>كۈچلۈك</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="231"/>
        <source>Medium</source>
        <translation>ئوتتۇراھال كۈچلۈك</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="240"/>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="253"/>
        <source>A stronger password is recommended: more than 8 characters, and contains 3 of the four character types: lowercase letters, uppercase letters, numbers, and symbols.</source>
        <translation>پارول8خانىدىن يۇقىرى بولىشىنى تەۋسىيە قىلىمىز،ئوخشاشلا چوڭ-كىچىك يېزىش،سان-ھەرپلەردىن ئۈچ خىلى بار بولسۇن </translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="244"/>
        <source>Weak</source>
        <translation>ئاجىز</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="255"/>
        <source>Error occurred when reading the configuration files of password rules!</source>
        <translation>پارول قائىدىسىنىڭ سەپلىمە ھۆججەتلىرىنى ئوقۇغاندا خاتالىق كۆرۈلدى!</translation>
    </message>
</context>
<context>
    <name>PinCodeDialog</name>
    <message>
        <location filename="../dde-bluetooth-dialog/src/pincodedialog.cpp" line="40"/>
        <source>The PIN for connecting to the Bluetooth device is:</source>
        <translation>ئۇلاش PIN نومۇرى:</translation>
    </message>
    <message>
        <location filename="../dde-bluetooth-dialog/src/pincodedialog.cpp" line="49"/>
        <source>Cancel</source>
        <translation>بىكار قىلىش</translation>
    </message>
    <message>
        <location filename="../dde-bluetooth-dialog/src/pincodedialog.cpp" line="51"/>
        <source>Confirm</source>
        <translation> جەزملەش</translation>
    </message>
</context>
<context>
    <name>ProcessInfoModel</name>
    <message>
        <location filename="../dmemory-warning-dialog/src/processinfomodel.cpp" line="111"/>
        <source>End</source>
        <translation>قويۇپ بېرىش</translation>
    </message>
</context>
<context>
    <name>PwqualityManager</name>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="76"/>
        <source>Password cannot be empty</source>
        <translation>پارول قۇرۇق قالسا بولمايدۇ</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="77"/>
        <source>Password must have at least %1 characters</source>
        <translation>پارول %1 ھەرپتىن كەم بولماسلىقى كېرەك</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="78"/>
        <source>Password must be no more than %1 characters</source>
        <translation>پارول %1 ھەرپتىن ئېشىپ كەتمەسلىكى كېرەك</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="79"/>
        <source>Password can only contain English letters (case-sensitive), numbers or special symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
        <translation>پارولدا پەقەت ئىنگلىزچە ھەرپلەر (چوڭ-كىچىك) ، سان ياكى ئالاھىدە بەلگىلەر بار (~! @ # $% ^ &amp; * () [] {} \ | /?,. &lt;&gt;)</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="80"/>
        <source>No more than %1 palindrome characters please</source>
        <translation>جاۋاب خەتنىڭ ئۇزۇنلۇقى %1 ھەرپتىن ئېشىپ كەتمىسۇن</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="81"/>
        <source>No more than %1 monotonic characters please</source>
        <translation>قايتىلانغان بەلگە %1 تىن ئېشىپ كەتمىسۇن</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="82"/>
        <source>No more than %1 repeating characters please</source>
        <translation>قايتىلانغان ھەرپ %1 تىن ئېشىپ كەتمىسۇن</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="87"/>
        <source>Password must contain uppercase letters, lowercase letters, numbers and symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
        <translation>پارول چوڭ ھەرپ،كىچىك ھەرپ، سانلار ۋە بەلگىلەردىن ئىبارەت ئۈچ تۈرنى ئۆز ئىچىگە ئېلىشى كېرەك(~!@#$%^&amp;*()[]{}\|/?,.&lt;&gt;)</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="88"/>
        <source>Password must not contain more than 4 palindrome characters</source>
        <translation>پارولدا ئۇدا 4 تىن ئارتۇق قايتىلانما ھەرپ-بەلگە بولسا بولمايدۇ</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="89"/>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="92"/>
        <source>Do not use common words and combinations as password</source>
        <translation>پارولدا دائىم ئۇچرايدىغان ئاددىي سۆز ۋە سۆز بىرىكمىلىرى بولسا بولمايدۇ</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="90"/>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="91"/>
        <source>Create a strong password please</source>
        <translation>پارول بەك ئاددىي، مۇرەككەپرەك بېكىتىڭ</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="97"/>
        <source>It does not meet password rules</source>
        <translation>پارول بىخەتەرلىك تەلىپىگە ئۇيغۇن كەلمەيدۇ</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="43"/>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="49"/>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="59"/>
        <source>Password</source>
        <translation>پارول</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="44"/>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="45"/>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="46"/>
        <source>Key</source>
        <translation>پارول</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="47"/>
        <source>key</source>
        <translation>ئاچقۇچ</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="55"/>
        <source>Private Pwd</source>
        <translation>شەخسىي پارول</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="58"/>
        <source>Proxy Password</source>
        <translation>ۋاكالەتچى پارولى</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="60"/>
        <source>Group Password</source>
        <translation>گۇرۇپپا پارول</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/utils.h" line="71"/>
        <source>It cannot be empty</source>
        <translation> قۇرۇق قويۇشقا بولمايدۇ</translation>
    </message>
</context>
<context>
    <name>ResetPasswordDialog</name>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="110"/>
        <source>Resetting the password will clear the data stored in the keyring</source>
        <translation>پارولنى قايتا بېكىتسىڭىز مەخپىي ئاچقۇچ ھالقىسىدا ساقلانغان سانلىق مەلۇماتلار تازىلىنىدۇ</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="112"/>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="168"/>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="210"/>
        <source>Cancel</source>
        <translation>بىكار قىلىش</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="121"/>
        <source>Security Questions</source>
        <translation>بىخەتەرلىك سوئاللىرى</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="156"/>
        <source>Reset Password</source>
        <translation>پارولنى قايتا بېكىتىش</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="157"/>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="195"/>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="198"/>
        <source>Next</source>
        <translation>كېيىنكى </translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="160"/>
        <source>Reset Password By Union ID</source>
        <translation>Union ID نىڭ پارولىنى قايتا بېكىتىش</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="161"/>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="195"/>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="198"/>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="206"/>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="213"/>
        <source>Reset</source>
        <translation>قايتا بېكىتىش</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="167"/>
        <source>Resetting the password will clear the data stored in your keyring, and you should log in again, please save files in advance</source>
        <translation>پارولنى قايتا بېكىستسىڭىز مەخپىي ئاچقۇچ ھالقىسىدا ساقلانغان سانلىق مەلۇماتلار تازىلىنىدۇ، ھەمدە بۇ ئىشلەتكۈچى قايتىدىن كىرىدۇ، ھۆججەتلىرىڭىزنى ئالدىن ساقلاشقا دىققەت قىلىڭ</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="168"/>
        <source>Confirm and Reset</source>
        <translation>قايتا بېكىتشىنى جەزملەش</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="264"/>
        <source>Successfully reset, please log in and unlock with the new password</source>
        <translation>پارول قايتا بېكىتىلدى، يېڭى پارولدا كىرىڭ</translation>
    </message>
</context>
<context>
    <name>SecurityQuestionsWidget</name>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="127"/>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="128"/>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="129"/>
        <source>Required</source>
        <translation>چوقۇم تولدۇرۇڭ</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="131"/>
        <source>What&apos;s the name of the city where you were born?</source>
        <translation>سىز تۇغۇلغان شەھەرنىڭ نامى نېمە؟</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="132"/>
        <source>What&apos;s the name of the first school you attended?</source>
        <translation>مەكتىپىڭىزنىڭ نامى نېمە؟</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="133"/>
        <source>Who do you love the most in this world?</source>
        <translation>سىز كىمنى ئەڭ ياخشى كۆرىسىز؟</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="134"/>
        <source>What&apos;s your favorite animal?</source>
        <translation>سىز ئەڭ ياخشى كۆرىدىغان ھايۋان قايسى؟</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="135"/>
        <source>What&apos;s your favorite song?</source>
        <translation>سىز ئەڭ ياخشى كۆرىدىغان مۇزىكا قايسى؟</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="136"/>
        <source>What&apos;s your nickname?</source>
        <translation>تەخەللۇسىڭىز نېمە؟</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="186"/>
        <source>Wrong answer</source>
        <translation>جاۋاب خاتا</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="201"/>
        <source>Keep the answer under 30 characters</source>
        <translation>جاۋابىڭىز 30 ھەرپتىن ئاز بولسۇن</translation>
    </message>
</context>
<context>
    <name>SuspendDialog</name>
    <message>
        <location filename="../dde-suspend-dialog/src/suspenddialog.cpp" line="39"/>
        <source>External monitor detected, suspend?</source>
        <translation>سىرتقى ئېكران بايقالدى، تاقامسىز؟</translation>
    </message>
    <message>
        <location filename="../dde-suspend-dialog/src/suspenddialog.cpp" line="39"/>
        <location filename="../dde-suspend-dialog/src/suspenddialog.cpp" line="65"/>
        <source>%1s</source>
        <translation>%1 سىكۇنت</translation>
    </message>
    <message>
        <location filename="../dde-suspend-dialog/src/suspenddialog.cpp" line="54"/>
        <source>Cancel</source>
        <translation>بىكار قىلىش</translation>
    </message>
    <message>
        <location filename="../dde-suspend-dialog/src/suspenddialog.cpp" line="54"/>
        <source>Suspend</source>
        <translation>ئېسىپ قويۇش</translation>
    </message>
</context>
<context>
    <name>TouchscreenSetting</name>
    <message>
        <location filename="../dde-touchscreen-dialog/src/touchscreensetting.cpp" line="45"/>
        <source>Select your touch screen</source>
        <translation>چەكمە ئېكراننى تاللاش</translation>
    </message>
    <message>
        <location filename="../dde-touchscreen-dialog/src/touchscreensetting.cpp" line="55"/>
        <source>Cancel</source>
        <translation>بىكار قىلىش</translation>
    </message>
    <message>
        <location filename="../dde-touchscreen-dialog/src/touchscreensetting.cpp" line="56"/>
        <source>Confirm</source>
        <translation>جەزملەشتۈرۈش</translation>
    </message>
</context>
<context>
    <name>UnionIDWidget</name>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="63"/>
        <source>Phone/Email</source>
        <translation>تېلېفون/ئېلخەت</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="69"/>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="136"/>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="289"/>
        <source>Get Code</source>
        <translation>دەلىللەش كودىغا ئېرىشىش</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="89"/>
        <source>Connecting to the Internet...</source>
        <translation>تور ئۇلىنىۋاتىدۇ...</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="101"/>
        <source>The user account is not linked to Union ID</source>
        <translation>ھازىرقى  ھېسابات  نومۇرى Union IDغا باغلانمىغان</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="114"/>
        <source>Network disconnected, please retry after connected</source>
        <translation>تور ئۇلىنىشى ئۈزۈلدى، ئۇلىغاندىن كىيىن قايتا سىناپ بېقىڭ</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="134"/>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="135"/>
        <source>Required</source>
        <translation>چوقۇم تولدۇرۇڭ</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="170"/>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="185"/>
        <source>Phone/Email format is incorrect</source>
        <translation>تېلېفون/ئېلخەت فورماتى خاتا</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="239"/>
        <source>System error</source>
        <translation>سىستېما خاتالىقى </translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="241"/>
        <source>Login expired, please sign in to the Union ID again</source>
        <translation>كىرىش ۋاقتى ئۆتۈپ كەتكەن , Union ID قايتا كىرىڭ</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="243"/>
        <source>Network error</source>
        <translation>تور خاتالىقى</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="245"/>
        <source>You have reached the number limit to get the code today</source>
        <translation>بۈگۈنكى دەلىللەش كودىغا ئېرىشىش سانىڭىز توشتى</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="246"/>
        <source>The Union ID is not linked to a user account</source>
        <translation>بۇ Union ID يەرلىك ھېسابات نومۇرىغا باغلانمىغان </translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="255"/>
        <source>It cannot be empty</source>
        <translation> قۇرۇق قويۇشقا بولمايدۇ</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="292"/>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="334"/>
        <source>Resend (%1s)</source>
        <translation> قايىتىدىن ئېرىشش (%1s)</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="353"/>
        <source>Failed to get the code</source>
        <translation>كودقا ئېرىشەلمىدى</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="376"/>
        <source>Wrong verification code</source>
        <translation>دەلىللەش كودى خاتا</translation>
    </message>
</context>
<context>
    <name>UpdateContent</name>
    <message>
        <location filename="../dde-welcome/src/updatecontent.cpp" line="45"/>
        <source>Welcome, system updated successfully</source>
        <translation>خۇش كەپسىز، سىستېما يېڭىلاندى</translation>
    </message>
    <message>
        <location filename="../dde-welcome/src/updatecontent.cpp" line="46"/>
        <source>Current Edition:</source>
        <translation>نۆۋەتتىكى نەشرى:</translation>
    </message>
    <message>
        <location filename="../dde-welcome/src/updatecontent.cpp" line="47"/>
        <source>Enter</source>
        <translation>ئىشلىتىشنى باشلاش</translation>
    </message>
</context>
<context>
    <name>WMChooser</name>
    <message>
        <location filename="../dde-wm-chooser/src/wmchooser.cpp" line="57"/>
        <source>Effect Mode</source>
        <translation>ئالاھىدە ئۈنۈم ھالىتى</translation>
    </message>
    <message>
        <location filename="../dde-wm-chooser/src/wmchooser.cpp" line="60"/>
        <source>Normal Mode</source>
        <translation>نورمال ھالەت</translation>
    </message>
    <message>
        <location filename="../dde-wm-chooser/src/wmchooser.cpp" line="68"/>
        <source>It has detected that you are using a virtual machine, which will affect the system performance and operation experience, for a smooth experience, Normal Mode is recommended</source>
        <translation>مەۋھۇم ماشىنا ئىشلىتىۋاتقانلىقىڭىز بايقالدى، بۇ سىستېمىنىڭ ئىقتىدارى ۋە مەشغۇلات تۇيغۇسىغا تەسىر كۆرسىتىدۇ. مەۋھۇم ماشىنا شارائىتىدا سىستېمىنى ئوڭۇشلۇق ئىشلىتىش ئۈچۈن، نورمال ھالەتنى تاللاپ ئۈستەل يۈزىگە كىرىشىڭىز تەۋسىيە قىلىمىز.</translation>
    </message>
    <message>
        <location filename="../dde-wm-chooser/src/wmchooser.cpp" line="71"/>
        <source>Effect Mode: Have a delicate experience. Normal Mode: Enjoy the fast performance</source>
        <translation>ئالاھىدە ئۈنۈم ھالىتى: ئېسىل ۋە گۈزەل تۇيغۇدىن ھۇزۇرلىنىڭ؛ نورمال ھالەت: سىلىق ھەم تېز ئىقتىداردىن ھۇزۇرلىنىڭ</translation>
    </message>
    <message>
        <location filename="../dde-wm-chooser/src/wmchooser.cpp" line="64"/>
        <source>Friendly Reminder</source>
        <translation>دوستانە  ئەسكەرتىش </translation>
    </message>
</context>
<context>
    <name>WarningDialog</name>
    <message>
        <location filename="../dde-warning-dialog/src/warningdialog.cpp" line="38"/>
        <source>Kindly Reminder</source>
        <translation>سەمىمىي ئەسكەرتىش</translation>
    </message>
    <message>
        <location filename="../dde-warning-dialog/src/warningdialog.cpp" line="39"/>
        <source>This application cannot run without window effect</source>
        <translation>بۇ ئەپ ئېكران ئالاھىدە ھالىتىنى قوللىمايدۇ</translation>
    </message>
    <message>
        <location filename="../dde-warning-dialog/src/warningdialog.cpp" line="43"/>
        <source>OK</source>
        <translation>جەزىملەشتۈرۈش</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../dde-lowpower/src/window.cpp" line="41"/>
        <source>Low battery, please plug in</source>
        <translation>توك ئاز قالدى، توكقا چېتىڭ</translation>
    </message>
</context>
</TS>